@@ -38,6 +38,7 @@
 #include "interface.h"
 #include "packet_handler.h"
 #include "util.h"
+#include "callbacks.h"
 
 #include "gyachi_lib.h"
 #include "gy_config.h"
@@ -461,6 +462,7 @@ void on_captcha_entry_activate(GtkEditable *editable, gpointer user_data) {
 	on_captcha_ok_clicked((GtkWidget *)user_data, editable);
 }
 
+
 void on_captcha_cancel_clicked(GtkWidget *button, gpointer user_data) {
 	GtkWidget *tmp_widget;
 
@@ -471,6 +473,16 @@ void on_captcha_cancel_clicked(GtkWidget *button, gpointer user_data) {
 }
 
 
+/* ugly hack for requesting another captcha string.
+ * kill current UI,
+ * request room entry again...
+ */
+void on_captcha_recaptcha_clicked(GtkWidget *button, gpointer user_data) {
+	on_captcha_cancel_clicked(button, user_data);
+	on_goto_room_clicked((GtkButton *)button, user_data);
+}
+
+
 GtkWidget *build_captcha(GtkWidget *parent, char *label_text)  {
 	GtkWidget *window;
 	GtkWidget *vbox;
@@ -479,6 +491,7 @@ GtkWidget *build_captcha(GtkWidget *parent, char *label_text)  {
 	GtkWidget *hbox;	
 	GtkWidget *ok_button;
 	GtkWidget *cancel_button;
+	GtkWidget *recaptcha_button;
 
 	if (capture_fp) {
 		fprintf(capture_fp,"\n[%s] INFO-DIALOG MESSAGE: '%s'\n", gyach_timestamp(), _("Building Captcha"));
@@ -519,14 +532,21 @@ GtkWidget *build_captcha(GtkWidget *parent, char *label_text)  {
 	g_object_set_data(G_OBJECT(ok_button), "mywindow", window);
 	gtk_widget_show_all(ok_button);
 
+	recaptcha_button = get_pixmapped_button(_("Re-Captcha"), GTK_STOCK_REFRESH);
+	gyachi_set_tooltip(recaptcha_button, _("Get me another Captcha image because this one is really messed up!!!"));
+	g_object_set_data(G_OBJECT(recaptcha_button), "mywindow", window);
+	gtk_widget_show_all(recaptcha_button);
+
 	cancel_button=get_pixmapped_button(_("Cancel"), GTK_STOCK_CANCEL);
 	gyachi_set_tooltip(cancel_button, _("Cancel"));
 	g_object_set_data(G_OBJECT(cancel_button), "mywindow", window);
 	gtk_widget_show_all(cancel_button);
 
-	gtk_box_pack_start(GTK_BOX(hbox), ok_button,          FALSE, FALSE, 2);
-	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(" "), TRUE,  TRUE,  2);
-	gtk_box_pack_start(GTK_BOX(hbox), cancel_button,      FALSE, FALSE, 2);
+	gtk_box_pack_start(GTK_BOX(hbox), ok_button,          FALSE, FALSE, 1);
+	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(" "), TRUE,  TRUE,  0);
+	gtk_box_pack_start(GTK_BOX(hbox), recaptcha_button,      FALSE, FALSE, 1);
+	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(" "), TRUE,  TRUE,  0);
+	gtk_box_pack_start(GTK_BOX(hbox), cancel_button,      FALSE, FALSE, 1);
   	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 4);
 	gtk_widget_show(vbox);
 
@@ -538,6 +558,9 @@ GtkWidget *build_captcha(GtkWidget *parent, char *label_text)  {
 	g_signal_connect(G_OBJECT(ok_button), "clicked",
                       G_CALLBACK(on_captcha_ok_clicked), entry);
 
+	g_signal_connect(G_OBJECT(recaptcha_button), "clicked",
+                      G_CALLBACK(on_captcha_recaptcha_clicked), NULL);
+
 	g_signal_connect(G_OBJECT(cancel_button), "clicked",
                       G_CALLBACK(on_captcha_cancel_clicked), NULL);
 
