@@ -787,7 +787,7 @@ void cmd_url( char *url ) {
 			snprintf( buf, 398, 
 				"/emote is using %sGYach Enhanced %s v.%s  [%s%s%s] : Online for %d:%02d under %s  %s.  GYach Enhanced supports webcams, faders, Y! 'nicknames', and %spY! Voice Chat%s (the FIRST Y! voice chat program for Linux.)",
 				YAHOO_STYLE_BOLDON, YAHOO_STYLE_BOLDOFF, VERSION,
-				YAHOO_STYLE_URLON, GYACH_URL, YAHOO_STYLE_URLOFF,
+				YAHOO_STYLE_URLON, GYACHI_URL, YAHOO_STYLE_URLOFF,
 				hours, minutes, un.sysname, un.release, YAHOO_STYLE_BOLDON, YAHOO_STYLE_BOLDOFF);
 			chat_command( buf, 0 );
 		} else {
@@ -795,7 +795,7 @@ void cmd_url( char *url ) {
 				"%s%sGYachE Improved %s v.%s  [%s%s%s]  (currently OFFline) under %s %s.   GYach Enhanced supports webcams, faders, Y! 'nicknames', and %spY! Voice Chat%s (the FIRST Y! voice chat program for Linux.)\n",
 				YAHOO_COLOR_BLACK,
 				YAHOO_STYLE_BOLDON, YAHOO_STYLE_BOLDOFF, VERSION,
-				YAHOO_STYLE_URLON, GYACH_URL,  YAHOO_STYLE_URLOFF,
+				YAHOO_STYLE_URLON, GYACHI_URL,  YAHOO_STYLE_URLOFF,
 				un.sysname, un.release, YAHOO_STYLE_BOLDON, YAHOO_STYLE_BOLDOFF );
 			append_to_textbox( chat_window, NULL, buf );
 		}
@@ -1085,6 +1085,7 @@ void cmd_regex_test( char *args ) {
 	char *text;
 	char *match;
 	regex_t test_regex;
+	int rv;
 
 	strncpy( tmp, args, 255 );
 	ptr = strchr( tmp, '"' );
@@ -1123,8 +1124,12 @@ void cmd_regex_test( char *args ) {
 		ptr++;
 	}
 
-	regcomp( &test_regex, ptr, REG_EXTENDED | REG_ICASE | REG_NOSUB );
-	if ( ! regexec( &test_regex, text, 0, NULL, 0 )) {
+	rv = regcomp( &test_regex, ptr, REG_EXTENDED | REG_ICASE | REG_NOSUB );
+	if (rv) {
+		snprintf( msg,254,  "*** Gyach regex test: regex '%s' failed to compile.\n",
+			ptr );
+	}
+	else if ( ! regexec( &test_regex, text, 0, NULL, 0 )) {
 		/* matched */
 		snprintf( msg,254,  "*** Gyach regex test: '%s' matches using regex '%s'\n",
 			text, ptr );
