@@ -1064,6 +1064,7 @@ int check_clicked_text( char *text ) {
 	char *ptr;
 	regex_t url_regex;
 	int is_command=0;
+	int rv;
 #ifdef G_THREADS_ENABLED
 	GThread *prof_thread;
 #endif
@@ -1077,13 +1078,14 @@ int check_clicked_text( char *text ) {
 
 	ptr = NULL;
 	/* match anything with 3 strings separated by periods */
-	regcomp( &url_regex, URL_REGEX, REG_EXTENDED | REG_ICASE | REG_NOSUB );
+	rv = regcomp( &url_regex, URL_REGEX, REG_EXTENDED | REG_ICASE | REG_NOSUB );
+
 	if (( strstr( url, "http://" )) || ( strstr( url, "https://" )) || 
 		( strstr( url, "ftp://" )) || 
-		( ! regexec( &url_regex, url, 0, NULL, 0 ))) {
+		( !rv && !regexec( &url_regex, url, 0, NULL, 0 ))) {
 		ptr = strdup( url );
 	} else if ( ! strcasecmp( url, "gyach" )) {
-		ptr = strdup( GYACH_URL ); 
+		ptr = strdup( GYACHI_URL ); 
 	} else if  ( strstr( url, "y-mail://" ))  {
 		snprintf( url, 10, "%s", "/mail" );
 		ptr = strdup( url );
@@ -1106,7 +1108,7 @@ int check_clicked_text( char *text ) {
 	}
 	regfree( &url_regex );
 	if (is_command)  {
-	  chat_command(url, 0);
+		chat_command(url, 0);
 		free(ptr);
 		return( 0 );
 	}
@@ -1310,6 +1312,7 @@ gint chat_motion_notify(GtkWidget * widget, GdkEventMotion * event) {
 	gint buf_x, buf_y;
 	GdkModifierType state;
 	int valid_link = 0;
+	int rv;
 
 	if (event->is_hint) {
 		gdk_window_get_pointer(event->window, &x, &y, &state);
@@ -1330,10 +1333,10 @@ gint chat_motion_notify(GtkWidget * widget, GdkEventMotion * event) {
 	ch = get_word_at_pos( GTK_TEXT_VIEW(widget), buf_x, buf_y );
 
 	if (( ch ) && ( ch[0] )) {
-		regcomp( &url_regex, URL_REGEX, REG_EXTENDED | REG_ICASE | REG_NOSUB );
+		rv = regcomp( &url_regex, URL_REGEX, REG_EXTENDED | REG_ICASE | REG_NOSUB );
 		if (( strstr( ch, "http://" )) || ( strstr( ch, "https://" )) || 
 			( strstr( ch, "ftp://" )) || ( strstr( ch, "y-mail://" )) || 
-			( ! regexec( &url_regex, ch, 0, NULL, 0 ))) {
+			( !rv && !regexec( &url_regex, ch, 0, NULL, 0 ))) {
 
 			valid_link = 1;
 		} else if (( ! strcasecmp( ch, "gyach" )) ||
