@@ -75,6 +75,11 @@ gboolean update_transparent_background (GtkWidget *widget, GdkEventExpose *event
 gboolean redraw_notify_event (GtkWidget *widget, GdkEvent *event, gpointer user_data);
 #endif
 
+void on_vpaned_realized(GtkWidget *widget, gpointer user_data) {
+	gtk_paned_set_position( GTK_PANED( widget ), 0 );
+}
+
+
 /* standard gyach interface function decls */
 int ct_build() {
 	GtkWidget *hbox;
@@ -109,8 +114,6 @@ int ct_build() {
 	gtk_text_view_set_left_margin (top_text, 5);
 	gtk_text_view_set_right_margin (top_text, 5);
 
-	gtk_paned_set_position( GTK_PANED( vpaned ), 0 );
-
 	sw = gtk_scrolled_window_new( NULL, NULL );
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
@@ -128,11 +131,15 @@ int ct_build() {
 
 	gtk_widget_show_all( vpaned );
 
+	g_signal_connect(G_OBJECT (vpaned), "realize", G_CALLBACK(on_vpaned_realized), NULL);
+
+#if 0
 	g_signal_connect(G_OBJECT (top_text), "button-press-event",
 		G_CALLBACK(on_chat_text_clicked), NULL);
 
 	g_signal_connect_after(G_OBJECT(top_text), "motion-notify-event",
 		G_CALLBACK(chat_motion_notify), NULL);
+#endif
 
 	GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(top_text), GTK_CAN_FOCUS);
 
@@ -142,11 +149,13 @@ int ct_build() {
 	gtk_widget_set_size_request(GTK_WIDGET(chat_text), 480, -1);
 	gtk_widget_show( GTK_WIDGET(chat_text) );
 
+#if 0
 	g_signal_connect(G_OBJECT (chat_text), "button-press-event",
 		G_CALLBACK(on_chat_text_clicked), NULL);
 
 	g_signal_connect_after(G_OBJECT(chat_text), "motion-notify-event",
 		G_CALLBACK(chat_motion_notify), NULL);
+#endif
 
 	GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(chat_text), GTK_CAN_FOCUS);
 
@@ -253,8 +262,7 @@ int remove_extra_lines() {
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 
-static GdkPixmap *
-shade_pixmap_gdk (GtkTextView *text, Pixmap p, int x, int y, int w, int h)
+static GdkPixmap *shade_pixmap_gdk (GtkTextView *text, Pixmap p, int x, int y, int w, int h)
 {
 	GdkPixmap *pp, *tmp, *shaded_pixmap;
 	GdkPixbuf *pixbuf;
@@ -298,7 +306,7 @@ shade_pixmap_gdk (GtkTextView *text, Pixmap p, int x, int y, int w, int h)
 		pixbuf = gdk_pixbuf_get_from_drawable (NULL, pp, cmap,
 						       x, y, 0, 0, w, h);
 	}
-	g_free (pp);
+	g_object_unref(pp);
 
 	if (!pixbuf)
 		return NULL;
@@ -345,7 +353,7 @@ shade_pixmap_gdk (GtkTextView *text, Pixmap p, int x, int y, int w, int h)
 	{
 		gdk_pixbuf_render_pixmap_and_mask (pixbuf, &shaded_pixmap, NULL, 0);
 	}
-	g_object_unref (pixbuf);
+	g_object_unref(pixbuf);
 
 	return shaded_pixmap;
 }
@@ -745,7 +753,7 @@ int ct_capture_to_file( char *filename ) {
 
 	length = gtk_text_buffer_get_char_count( text_buffer );
 
-	fprintf( fp, "\nGyach Enhanced, version %s\nCopyright (c) 2003-2005, Erica Andrews\n%s\nLicense: GNU General Public License\n\nCHAT/CONFERENCE SESSION LOG\n", VERSION, GYACH_URL );
+	fprintf( fp, "\nGyach Enhanced, version %s\nCopyright (c) 2003-2005, Erica Andrews\n%s\nLicense: GNU General Public License\n\nCHAT/CONFERENCE SESSION LOG\n", VERSION, GYACHI_URL );
 	fprintf( fp, "%s", ctime(&time_llnow ) );
 	fprintf( fp, "\n_____________________\n\n" );
 	fflush( fp );
@@ -904,6 +912,21 @@ gboolean on_chat_text_clicked(GtkWidget *widget, GdkEventButton  *event, gpointe
 	gint buf_x, buf_y;
 	gchar *ptr;
 
+#if 0
+	int chat_tab;
+	int current_tab;
+	GtkWidget *tmp_widget=NULL;
+
+	tmp_widget=g_object_get_data(G_OBJECT(chat_window),"gynotebook");
+	if (tmp_widget) {
+		current_tab = gtk_notebook_get_current_page((GtkNotebook *)tmp_widget);
+		chat_tab = find_tab_posn(CHAT_TAB);
+		if (chat_tab != current_tab) {
+			return FALSE;
+		}
+	}
+#endif
+	
 	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
 		x = event->x;
 		y = event->y;
