@@ -107,12 +107,9 @@ void set_base_url(char *some_url) {
 	if (mbase) {*mbase='\0';}
 	mbase=mybaseurl;
 	//printf("setbase:  %s\n", mbase); fflush(stdout);
-
 }
 
-void
-html_cancel_stream (HtmlStream *stream,  gpointer    user_data,  gpointer    cancel_data)
-{
+void html_cancel_stream (HtmlStream *stream,  gpointer    user_data,  gpointer    cancel_data) {
         // g_print ("CANCEL!!\n");
         /* Not sure what to do here */
 }
@@ -130,11 +127,12 @@ char *process_httpurl(const gchar *url) {
 	}
 	if (! strstr(url,"http://") ) {
 		if (strstr(url,"://")) {return "";}  /* some other protocol */
-									} else    {
+	}
+	else {
 		snprintf(myurl,350, "%s", url);
 		murl=myurl;
 		return murl;
-												}
+	}
 	
 	snprintf(myurl,350,"%s",url);
 	if (strlen(url)>0 && (! strstr(url,"http://") ))  {
@@ -186,6 +184,14 @@ void load_local_document(HtmlDocument *doc, char *filename) {
 	if (!filename) {return;}
 	if (strlen(filename)<5) {return;}
 
+	if (!htmlbuf) {
+		htmlbuf=malloc(MY_YAHOO_DATASIZE);
+	}
+
+	if (!htmlbuf)  {
+		return;
+	}
+
 	if ( stat( filename+5, &sbuf )) {
 		/* file doesn't exist so exit */  
 		snprintf(html_about_blank, sizeof(html_about_blank)-1, "%s<br>Could not open local file: %s",html_fallback, filename+5);
@@ -204,6 +210,7 @@ void load_local_document(HtmlDocument *doc, char *filename) {
 		html_document_close_stream (doc);
 		return;
 	}
+
 	sprintf(htmlbuf,"%s", "");
 	bytes = read( fd, filebuf, 512 );
 	while( bytes && (grabbed<maxreadin)) {
@@ -216,6 +223,11 @@ void load_local_document(HtmlDocument *doc, char *filename) {
 	html_document_write_stream (doc, htmlbuf, grabbed);
 	html_document_close_stream (doc);
 	gtk_entry_set_text(GTK_ENTRY(myurlentry),filename);
+
+	if (htmlbuf) {
+		free(htmlbuf);
+		htmlbuf=NULL;
+	}
 }
 
 
@@ -225,38 +237,56 @@ void load_yahprofile(HtmlDocument *doc, char *some_url) {
 	char *starter=NULL;
 	char *ender=NULL;
 
+	if (!htmlbuf) {
+		htmlbuf=malloc(MY_YAHOO_DATASIZE);
+	}
+
+	if (!htmlbuf)  {
+		return;
+	}
+
 	url_length = fetch_url( some_url, htmlbuf, MY_YAHOO_DATASIZE-1, NULL, ymsg_sess->cookie );  
-	if (url_length<5) {snprintf(htmlbuf, 1024, "%s",html_fallback);}
+	if (url_length<5) {
+		strcpy(htmlbuf, html_fallback);
+	}
 
 	starter=strstr(htmlbuf, "<table cellspacing=0 width=\"100%\" cellpadding=2 border=0>");
 	if (starter) {
-	ender=strstr(starter, "<table border=\"0\" cellpadding=\"4\" cellspacing=\"0\" width=\"750\">");
-
+		ender=strstr(starter, "<table border=\"0\" cellpadding=\"4\" cellspacing=\"0\" width=\"750\">");
 	}
 
 	html_document_open_stream (doc, "text/html");
 
-	if (starter && ender && strstr(starter, "</td>\n<td width=\"1%\">"))   {
+	if (starter && ender && strstr(starter, "</td>\n<td width=\"1%\">")) {
 		char *clipper=NULL;
 		*ender='\0';
 		clipper=strstr(starter, "</td>\n<td width=\"1%\">");
 		while (clipper) {
-			if (!strstr(clipper+1, "</td>\n<td width=\"1%\">")) {break;}
+			if (!strstr(clipper+1, "</td>\n<td width=\"1%\">")) {
+				break;
+			}
 			clipper=strstr(clipper+1, "</td>\n<td width=\"1%\">");
 		}
 		if (clipper)  {
-			char *duppy=malloc(strlen (starter)+325);
+			char *duppy=malloc(strlen(starter)+325);
+
+			duppy[strlen(starter)+325-2]=0;
 			*clipper='\0';
-			snprintf(duppy,strlen (starter)+325-2, "<body bgcolor=\"#FFFFFF\" text=\"#000000\"><font face=\"Arial\" size=\"+1\"><b>%s's Profile</b></font><br> &nbsp; <br><table cellspacing=0 width=\"98%%\" cellpadding=2 border=0><td>%s</td></tr></table>", some_url+26, starter);
+			snprintf(duppy, strlen(starter)+325-2, "<body bgcolor=\"#FFFFFF\" text=\"#000000\"><font face=\"Arial\" size=\"+1\"><b>%s's Profile</b></font><br> &nbsp; <br><table cellspacing=0 width=\"98%%\" cellpadding=2 border=0><td>%s</td></tr></table>", some_url+26, starter);
 			html_document_write_stream (doc, duppy, strlen (duppy));
 			free(duppy);
 			it_printed=1;
 		}
 	}
 
-	if (!it_printed) {html_document_write_stream (doc, htmlbuf, strlen (htmlbuf));}
+	if (!it_printed) {
+		html_document_write_stream (doc, htmlbuf, strlen (htmlbuf));
+	}
 	html_document_close_stream (doc);
-	if (htmlbuf) {free(htmlbuf); htmlbuf=NULL;}
+	if (htmlbuf) {
+		free(htmlbuf);
+		htmlbuf=NULL;
+	}
 }
 
 
@@ -271,21 +301,25 @@ void load_html_document(HtmlDocument *doc, char *some_url) {
 		snprintf(currenturl,350,"%s",some_url);
 		if (!strcasecmp(some_url, "about:blank"))  {
 			snprintf(html_about_blank, sizeof(html_about_blank)-1, "<body bgcolor=\"#EFF3F7\" text=\"#000000\" link=\"#000099\" vlink=\"#880000\"><center><br><b><font size=\"6\"  color=\"#660099\">GyachE Improved</font><font size=\"4\" color=\"#000088\"><br>%s<br><br><a href=\"%s\">%s</a><br><br>_______________________<br><br>"
-				 "</font><font size=\"3\" color=\"#000000\"><i>Copyright (c) 2007-2008, Gregory D. Hosler</i><br>"
+				 "</font><font size=\"3\" color=\"#000000\"><i>Copyright (c) 2007-2010, Gregory D. Hosler</i><br>"
 				 "</font><font size=\"3\" color=\"#000000\"><i>Copyright (c) 2006, Stefan Sikora and Zoltan Csala</i><br>"
 				 "<br>"
 				 "GHosler ['at'] users.sourceforge.net<br>"
 				 "HdHoshy ['at'] users.sourceforge.net<br>"
 				 "ZCsala021 ['at'] users.sourceforge.net<br>"
 				 "<br>"
-				 "License: GNU General Public License</font></center>", VERSION, GYACH_URL, GYACH_URL); 
+				 "License: GNU General Public License</font></center>", VERSION, GYACHI_URL, GYACHI_URL); 
 			url_length=strlen(html_about_blank);
-			if (htmlbuf) {free(htmlbuf); htmlbuf=NULL;}
+			if (htmlbuf) {
+				free(htmlbuf);
+				htmlbuf=NULL;
+			}
 			html_document_open_stream (doc, "text/html");
 			html_document_write_stream (doc, html_about_blank, url_length);
 			html_document_close_stream (doc);
 			return;
-		} else {
+		}
+		else {
 			if (!htmlbuf)  {htmlbuf=malloc(MY_YAHOO_DATASIZE); }
 			if (!htmlbuf)  {
 				snprintf(html_about_blank, sizeof(html_about_blank)-1, "%s", html_fallback);
@@ -297,23 +331,31 @@ void load_html_document(HtmlDocument *doc, char *some_url) {
 			sprintf(htmlbuf,"%s", "");
 			if (!strncasecmp(some_url,"file:", 5)) {
 				load_local_document(doc, some_url);
-				if (htmlbuf) {free(htmlbuf); htmlbuf=NULL;}
+				if (htmlbuf) {
+					free(htmlbuf);
+					htmlbuf=NULL;
+				}
 				return;
-			} else {
+			}
+			else {
 				if (!strncasecmp(some_url,"http://profiles.yahoo.com/", 26))  {
-				  load_yahprofile(doc, some_url);
-				  return;
+					load_yahprofile(doc, some_url);
+					return;
 				}
 				/* Yahoo 'tear-off pages for My Yahoo are normally very small */
 				url_length = fetch_url( some_url, htmlbuf, MY_YAHOO_DATASIZE-1, NULL, ymsg_sess->cookie );  
 			}
 		}
 	}
-	else {return; }  /* invalid/missing url */
+	else {
+		return;		/* invalid/missing url */
+	}
 
 	/* printf("GOT URL:  %s\n", some_url); fflush(stdout);  */
 	
-	if (url_length<5) {snprintf(htmlbuf, 1024, "%s",html_fallback);}
+	if (url_length<5) {
+		strcpy(htmlbuf, html_fallback);
+	}
 
 	if (! strcasecmp(some_url,"http://my.yahoo.com/tearoff/channel.html"))  {
 		/* clean up some stuff that screws up news page margins */
@@ -343,25 +385,12 @@ void load_html_document(HtmlDocument *doc, char *some_url) {
 		}
 		cleaner=strstr(htmlbuf,"<small>");
 		while (cleaner) {
-			*cleaner=' ';
-			*(cleaner+1)=' ';
-			*(cleaner+2)=' ';
-			*(cleaner+3)=' ';
-			*(cleaner+4)=' ';
-			*(cleaner+5)=' ';
-			*(cleaner+6)=' ';
+			memset(cleaner, ' ', 7);
 			cleaner=strstr(htmlbuf,"<small>");
 		}
 		cleaner=strstr(htmlbuf,"</small>");
 		while (cleaner) {
-			*cleaner=' ';
-			*(cleaner+1)=' ';
-			*(cleaner+2)=' ';
-			*(cleaner+3)=' ';
-			*(cleaner+4)=' ';
-			*(cleaner+5)=' ';
-			*(cleaner+6)=' ';
-			*(cleaner+7)=' ';
+			memset(cleaner, ' ', 8);
 			cleaner=strstr(htmlbuf,"</small>");
 		}
 	}
@@ -373,8 +402,8 @@ void load_html_document(HtmlDocument *doc, char *some_url) {
 }
 
 /* This method is for throwing random HTML strings
-    to the HTML widget, such as the HTML-formatted
-    strings that come with the new Y! Messenger 'new alert' packets  
+   to the HTML widget, such as the HTML-formatted
+   strings that come with the new Y! Messenger 'new alert' packets  
 */
 
 void set_myyahoo_html_data(char *myhtmldata) {
@@ -388,14 +417,14 @@ void set_myyahoo_html_data(char *myhtmldata) {
 		html_document_write_stream (myahoodoc, html_about_blank, strlen(html_about_blank));
 		html_document_close_stream (myahoodoc);
 		return;
-		}
+	}
 	url_length=snprintf(htmlbuf,9000, "<body bgcolor=\"#FFFFFF\"><table border=\"0\" cellpadding=\"5\" width=\"98%%\"><tr><td width=\"100%%\">%s", myhtmldata);
 	strcat(htmlbuf,"</td></tr></table><br>");
 	html_document_open_stream (myahoodoc, "text/html");
 	html_document_write_stream (myahoodoc, htmlbuf, strlen (htmlbuf));
 	html_document_close_stream (myahoodoc);
 	gtk_entry_set_text(GTK_ENTRY(myurlentry),"alert:News");
-	snprintf(htmlbuf, 128, "%sindex.php", GYACH_URL);
+	snprintf(htmlbuf, 128, "%sindex.php", GYACHI_URL);
 	set_base_url(htmlbuf); 
 }
 
@@ -409,11 +438,13 @@ void open_my_yahoo(GtkButton *widget, gpointer user_data) {
 	const char *mycat;
 	char *pref_page=NULL;
 	char turl[112]="";
-	if (!myahoodoc) {return;}
+	if (!myahoodoc) {
+		return;
+	}
 	if (!logged_in) {
-	 snprintf(turl,32, "%s", "about:blank");
-	 load_myyahoo_URL(turl);
-	 return;
+		snprintf(turl,32, "%s", "about:blank");
+		load_myyahoo_URL(turl);
+		return;
 	}
 
 	mycat=gyachi_combobox_get_selected_item(myyahcombo);
@@ -445,7 +476,8 @@ void open_my_yahoo(GtkButton *widget, gpointer user_data) {
 		tvtm_now = localtime( &tvtime_now);
 		snprintf(turl, 110, "http://uk.horoscope.yahoo.com/daily/%d%02d%02d/%s.html",
 		tvtm_now->tm_year+1900, tvtm_now->tm_mon+1, tvtm_now->tm_mday, pref_page);  
-	} else {
+	}
+	else {
 		/* Set the basic base URL */
 		snprintf(turl, 32, "%s", "http://my.yahoo.com/preview/"); 
 	}
@@ -577,18 +609,25 @@ void url_requested (HtmlDocument *html, const gchar *url, HtmlStream *html_strea
 
 	if (strstr(url, "/my/next.gif")) {
 		myurl=strdup("http://www.digitallords.com/icons/forward.png");
-	} else if (strstr(url, "/my/prev.gif")) {
+	}
+	else if (strstr(url, "/my/prev.gif")) {
 		myurl=strdup("http://www.digitallords.com/icons/back.png");
-	} else if (strstr(url, "/my/arrowdown.gif")) {
+	}
+	else if (strstr(url, "/my/arrowdown.gif")) {
 		myurl=strdup("http://www.digitallords.com/icons/down.png");
-	} else if (strstr(url, "/bc/sfld.gif")) {
+	}
+	else if (strstr(url, "/bc/sfld.gif")) {
 		myurl=strdup("http://www.digitallords.com/icons/folder.png");
-	} else {
-	myurl=strdup(process_httpurl(url));
-		}
+	}
+	else {
+		myurl=strdup(process_httpurl(url));
+	}
 
 	if (! myurl) {return;}
-	if (strlen(myurl)<1) { free(myurl); return;}
+	if (strlen(myurl)<1) {
+		free(myurl);
+		return;
+	}
 
 	html_stream_set_cancel_func (html_stream, html_cancel_stream, NULL);
 
@@ -600,16 +639,14 @@ void url_requested (HtmlDocument *html, const gchar *url, HtmlStream *html_strea
 
   	fd = open (tfile, O_RDONLY);
 
-  	if (fd < 0)
- 	 {
-    	return;
+  	if (fd < 0) {
+	    	return;
   	}	
 
-  	for (; (len = read (fd, buf, 512)) > 0; )
-  	{
-   	 html_stream_write (html_stream, buf, len);
+  	for (; (len = read (fd, buf, 512)) > 0; ) {
+		html_stream_write (html_stream, buf, len);
   	}
- 	 close (fd);
+	close (fd);
 	
 	unlink(tfile);
 }
@@ -687,8 +724,6 @@ void on_myyahoo_zoomout(GtkButton *widget, gpointer user_data) {
 }
 
 
-
-
 GtkWidget *get_my_yahoo_panel() {
 	GtkWidget *mypanel;
 	GtkWidget *hbox1;
