@@ -182,6 +182,7 @@ int ignore_check( char *user ) {
 
 void regex_add( char *regex ) {
 	regex_t *ai_regex;
+	int rv;
 
 	if ( ! regex ) {
 		// DBG( 11, "regex_add( NULL )\n" );
@@ -203,8 +204,31 @@ void regex_add( char *regex ) {
 	/* maintain the hash table of compiled regex structures */
 	if ( ! g_hash_table_lookup( regex_hash, regex )) {
 		ai_regex = malloc( sizeof( regex_t ));
-		regcomp( ai_regex, regex, REG_EXTENDED | REG_ICASE | REG_NOSUB );
-		g_hash_table_insert( regex_hash, g_strdup( regex ), ai_regex );
+		rv = regcomp( ai_regex, regex, REG_EXTENDED | REG_ICASE | REG_NOSUB );
+		if (rv) {
+			char *buff;
+			int buff_size;
+
+			buff_size = regerror(rv, ai_regex, NULL, 0);
+			buff = malloc(buff_size);
+			buff_size = regerror(rv, ai_regex, buff, buff_size);
+
+			if ( chat_timestamp ) {
+				append_timestamp(chat_window, NULL);
+				append_to_textbox(chat_window, NULL, " ");
+			}
+
+			append_to_textbox( chat_window, NULL, _("Error processing regular expression: '") );
+			append_to_textbox( chat_window, NULL,  regex);
+			append_to_textbox( chat_window, NULL, "' -- " );
+			append_to_textbox( chat_window, NULL, buff );
+			append_to_textbox( chat_window, NULL, "\n" );
+			free(buff);
+		}
+
+		if (!rv) {
+			g_hash_table_insert( regex_hash, g_strdup( regex ), ai_regex );
+		}
 	}
 }
 
@@ -274,8 +298,10 @@ char *auto_ignore_check( char *str ) {
 	this_regex = regex_list;
 	while( this_regex ) {
 		ai_regex = g_hash_table_lookup( regex_hash, this_regex->data );
-		if ( ! regexec( ai_regex, str, 0, NULL, 0 )) {
-			return( this_regex->data );
+		if (ai_regex) {
+			if ( ! regexec( ai_regex, str, 0, NULL, 0 )) {
+				return( this_regex->data );
+			}
 		}
 
 		this_regex = g_list_next( this_regex );
@@ -739,12 +765,15 @@ void regex_toggle( char *regex ) {
 int regex_match( char *regex_str, char *str ) {
 	regex_t regex;
 	int result = 0;
+	int rv;
 
-	regcomp( &regex, regex_str, REG_EXTENDED | REG_ICASE | REG_NOSUB );
-	if ( ! regexec( &regex, str, 0, NULL, 0 ))
-		result = 1;
+	rv = regcomp( &regex, regex_str, REG_EXTENDED | REG_ICASE | REG_NOSUB );
+	if ( !rv) {
+		if ( ! regexec( &regex, str, 0, NULL, 0 ))
+			result = 1;
 
-	regfree( &regex );
+		regfree( &regex );
+	}
 
 	return( result );
 }
