@@ -100,11 +100,53 @@ extern unsigned long sock_sleep;   /* flow control, added PhrozenSmoke, boot pre
 
 int real_show_colors = 1;
 static int bold = FALSE, italic = FALSE, underline = FALSE, url = FALSE;
+int tv_scroll_needed(GtkTextView *text_view);
+
+void do_tv_value_changed(GtkAdjustment *adj, gpointer user_data) {
+	GtkTextView *text_view = GTK_TEXT_VIEW(user_data);
+	GtkTextBuffer *text_buffer;
+	GtkTextMark *end_mark;
+	gdouble page_size,       *old_page_size;
+
+	page_size=gtk_adjustment_get_page_size(adj);
+
+
+	old_page_size      = g_object_get_data(G_OBJECT(user_data), "pms_page_size");
+
+	if (
+	    (old_page_size && (*old_page_size == page_size))
+	    ) {
+		return;
+	}
+
+	if (old_page_size) *old_page_size=page_size;
+
+	text_buffer = gtk_text_view_get_buffer( text_view );
+	if (! text_buffer ) {return;}
+	if (! text_view) {return;}
+	end_mark = gtk_text_buffer_get_mark( text_buffer, "end_mark" );
+	gtk_text_view_scroll_to_mark( text_view, end_mark, 0, FALSE, 0, 0 );
+}
+
+void tv_value_changed(GtkAdjustment *adj, gpointer user_data) {
+	do_tv_value_changed(adj, user_data);
+}
+
+void tv_changed(GtkAdjustment *adj, gpointer user_data) {
+	do_tv_value_changed(adj, user_data);
+}
+
+void tv_destroy(GtkAdjustment *adj, gpointer user_data) {
+	gdouble *old_page_size;
+	old_page_size = g_object_get_data(G_OBJECT(user_data), "pms_page_size");
+	if (old_page_size) free(old_page_size);
+}
 
 void tv_jump_to_bottom( GtkTextView *text_view) {
 	GtkTextIter end;
 	GtkTextBuffer *text_buffer;
 	GtkTextMark *end_mark;
+
 	text_buffer = gtk_text_view_get_buffer( text_view );
 	if (! text_buffer ) {return;}
 	if (! text_view) {return;}
@@ -113,23 +155,23 @@ void tv_jump_to_bottom( GtkTextView *text_view) {
 	gtk_text_buffer_get_iter_at_mark( text_buffer, &end, end_mark );
 	gtk_text_buffer_place_cursor( text_buffer, &end );		
 	gtk_text_view_scroll_to_mark( text_view, end_mark, 0, FALSE, 0, 0 );
-	/*  */   gtk_text_view_scroll_mark_onscreen( text_view, end_mark);
+	/* gtk_text_view_scroll_mark_onscreen( text_view, end_mark); */
 }
 
 int tv_scroll_needed(GtkTextView *text_view) {
 	GtkAdjustment *adj;
 	int scroller=0;
+
 	/* Scroll down if we aint scrolling up */
 	adj = text_view->vadjustment;
 	if (adj) {
 		if ( adj->value == ( adj->upper - adj->lower - adj->page_size )) {scroller=1;}
 		/* not right at the bottom, but very close ... */ 
 		if ( adj->value > ( adj->upper - adj->lower - adj->page_size -33 )) {scroller=1;}
+		/* page size 0 means new PM window... */
+		if ( adj->page_size == 0) { scroller=1;}
 	}
 
-		/* printf("targ: %f\n", (float) ( adj->upper - adj->lower - adj->page_size )); fflush(stdout); 
-		printf("adj: %f\n", (float) adj->value ); fflush(stdout);  */  
-
 	return scroller;
 }
 
@@ -371,7 +413,7 @@ void append_to_textbox(GtkWidget *window, GtkWidget *textbox, const char *intext
 		if ( ct_scroll_at_bottom() ) {scroll = TRUE;}
 	} else {
 		if (tv_scroll_needed(GTK_TEXT_VIEW(textbox) )) {scroll = TRUE;	}
-		if (! strchr(intext,'\n')) {scroll = FALSE;}
+//		if (! strchr(intext,'\n')) {scroll = FALSE;}
 	}
 
 	/* Reset all attributes - currently just color */
@@ -1199,7 +1241,6 @@ int main( int argc, char **argv ) {
 	}
 	update_fader_strings();
 	ymsg_sess->debug_packets = debug_packets;
-	ignore_load();
 	history_load();
 	smileys_load();
 
@@ -1302,7 +1343,7 @@ int main( int argc, char **argv ) {
 		 YAHOO_STYLE_ITALICON,
 		 "\033[#8F4CB1m",
 		 VERSION,
-		 GYACH_URL,
+		 GYACHI_URL,
 		 YAHOO_STYLE_ITALICOFF,
 		 YAHOO_COLOR_BLACK);
 	append_to_textbox_color( chat_window, NULL, buf );
@@ -1334,6 +1375,8 @@ int main( int argc, char **argv ) {
 
 	load_plugin_modules(display_message, GYACHI_PLUGINS);
 
+	ignore_load();
+
 	if (gyachi_sound_device) {
 		select_sound_device(gyachi_sound_device);
 	}
