@@ -121,7 +121,7 @@ int pm_capture_to_file( char *filename, GtkTextBuffer *mybuffer, GtkTextView *wi
 		 "Copyright 2006, Stefan Sikora and Zoltan Csala\n"
 		 "Copyright (c) 2003-2005, Erica Andrews\n"
 		 "%s\nLicense: GNU General Public License\n\n"
-		 "INSTANT MESSAGE SESSION LOG\n", VERSION, GYACH_URL );
+		 "INSTANT MESSAGE SESSION LOG\n", VERSION, GYACHI_URL );
 	fprintf( fp, "%s", ctime(&time_llnow ) );
 	fprintf( fp, "\n_____________________\n\n" );
 	fflush( fp );
@@ -749,6 +749,13 @@ GtkWidget *create_pm_session (char *forwho)
   g_signal_connect(G_OBJECT(GTK_TEXT_VIEW(pms_text)->vadjustment), "value-changed", G_CALLBACK(tuxviron_redraw_notify_event),NULL);
   g_signal_connect(G_OBJECT(pms_text), "configure-event", G_CALLBACK(tuxviron_redraw_notify_event), NULL);
 
+  /* debug */
+  gdouble *page_size=malloc(sizeof(gdouble));
+  g_object_set_data(G_OBJECT(pms_text),                            "pms_page_size", (gpointer)page_size);
+  g_signal_connect(G_OBJECT(GTK_TEXT_VIEW(pms_text)->vadjustment), "value-changed", G_CALLBACK(tv_value_changed), pms_text);
+  g_signal_connect(G_OBJECT(GTK_TEXT_VIEW(pms_text)->vadjustment), "changed",       G_CALLBACK(tv_changed), pms_text);
+  g_signal_connect(G_OBJECT(GTK_TEXT_VIEW(pms_text)->vadjustment), "destroy",       G_CALLBACK(tv_destroy), pms_text);
+
   hbox14 = gtk_hbox_new (FALSE, 0);
 
   if (pm_window_style==1) {
