@@ -602,8 +602,7 @@ int update_meter(gpointer data)
 
 	if ((file_info->status == SUCCESS)   ||
 	    (file_info->status == CANCELLED) ||
-	    (file_info->status == UNKNOWN)   ||
-	    (dl_tree == NULL))               {
+	    (file_info->status == UNKNOWN))   {
 		free_fxfile_info(file_info);
 		return(FALSE);
 	}
