@@ -61,8 +61,10 @@
 
 #include <gtk/gtk.h>
 
-#include "gyacheupload.h"
 #include "camcapt.h"
+#include "gyacheupload-v4l.h"
+#include "gyacheupload-ui.h"
+#include "gyacheupload-main.h"
 
 #include "gyachi_lib.h"
 #include "gytreeview.h"
@@ -658,12 +660,7 @@ gchar* on_print_value(GtkScale *scale, gdouble value, gpointer  user_data)
 }
 
 void shutdown_callback() {
-	if (exit_on_error) {
-		cam_app_quit=1;
-		cleanup_v4l();
-		mem_cleanup();
-		exit(-1);
-	}
+	cam_app_quit=1;
 }
 
 void show_error_dialog(char *mymsg, GtkWidget *parent) {
@@ -692,15 +689,14 @@ void on_close_ok_propw (GtkWidget *widget, GdkEvent *event, gpointer  user_data)
 
 void on_close_ok_prop (GtkWidget *widget, gpointer  user_data)
 {
-	GdkEvent *event;
-	on_close_ok_propw(widget, event, user_data);
+	on_close_ok_propw(widget, NULL, user_data);
 }
 
 void on_vid_prop_changed(GtkWidget *widget, gpointer  user_data)
 {
 	GtkRange      *range    = (GtkRange *)widget;
 	V4L_PROPERTY  *property = (V4L_PROPERTY *)user_data;
-	char          *parent   = g_object_get_data(G_OBJECT(widget), "parent");
+	GtkWidget     *parent   = g_object_get_data(G_OBJECT(widget), "parent");
 
 	if (property->v4l_version == 1) {
 		property->value = gtk_range_get_value(range);
@@ -757,8 +753,8 @@ void on_vid_prop_button_reset(GtkButton *button, gpointer  user_data)
 void on_tb_toggled(GtkWidget *widget, gpointer  user_data)
 {
 	GtkToggleButton *togglebutton = (GtkToggleButton *)widget;
-	V4L_PROPERTY  *property = (V4L_PROPERTY *)user_data;
-	char *parent=g_object_get_data(G_OBJECT(widget), "parent");
+	V4L_PROPERTY    *property = (V4L_PROPERTY *)user_data;
+	GtkWidget       *parent=g_object_get_data(G_OBJECT(widget), "parent");
 
 	property->value = gtk_toggle_button_get_active(togglebutton);
 
@@ -963,9 +959,6 @@ void on_about_menu(GtkMenuItem *menuitem, gpointer  user_data) {
 void on_shutdown_app(GtkWidget *widget, GdkEvent *event, gpointer  user_data)
 {	
 	cam_app_quit=1;
-	cleanup_v4l();
-	mem_cleanup();
-	exit(0);
 }
 
 void on_shutdown_app_cb(GtkMenuItem *menuitem, gpointer  user_data) {
