@@ -89,8 +89,7 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 
-#ifdef HAVE_LIBV4L
-#include <libv4l2.h>
+#ifdef HAVE_LIBV4L1
 #include <libv4l1.h>
 #else
 #define v4l1_open   open
@@ -99,7 +98,11 @@
 #define v4l1_read   read
 #define v4l1_mmap   mmap
 #define v4l1_munmap munmap
+#endif
 
+#ifdef HAVE_LIBV4L2
+#include <libv4l2.h>
+#else
 #define v4l2_open   open
 #define v4l2_close  close
 #define v4l2_ioctl  ioctl
@@ -115,9 +118,11 @@
 #include <linux/videodev2.h>
 
 
-#include "gyacheupload.h"
 #include "v4l-fmtconv.h"
 #include "camcapt.h"
+#include "gyacheupload-v4l.h"
+#include "gyacheupload-ui.h"
+#include "gyacheupload-main.h"
 
 #include "gyachi_lib.h"
 
